@@ -22,20 +22,19 @@ if __name__ == '__main__':
 
 
 def URLS(apps):
-    routes = [f"from {app['name']} import urls as {app['name']}_urls\n" for app in apps]
+    # routes = [f"from {app['name']} import urls as {app['name']}_urls\n" for app in apps]
+    # includes = []
+    # for app in apps:
+    #     includes.append(f"\tpath('{app['base_url']}', include({app['name']}_urls)),\n")
 
-    includes = []
-    for app in apps:
-        includes.append(f"\tpath('{app['base_url']}', include({app['name']}_urls)),\n")
-
-    return f"""from clixdev.projects import _urls
+    return f"""from clixdev.apps.clix import urls
 from django.contrib import admin
 from django.urls import path, include
 
 
 urlpatterns = [
 \tpath('admin/', admin.site.urls),
-\tpath('api/', include(_urls)),
+\tpath('api/', include(urls)),
 ]
 """
 # removed due to beta
@@ -77,7 +76,7 @@ INSTALLED_APPS = [
 \t'django.contrib.sessions',
 \t'django.contrib.messages',
 \t'django.contrib.staticfiles',
-
+\t'clixdev.apps.clix'
 ]
 
 MIDDLEWARE = [
@@ -178,7 +177,7 @@ application = get_wsgi_application()
 
 def VIEWS(app):
     endpoints = app['endpoints']
-    defs = ["import json\nfrom django.http import JsonResponse\nfrom django.views.decorators.csrf import csrf_exempt\n\nfrom clixdev.projects._models import *"]
+    defs = ["import json\nfrom django.http import JsonResponse\nfrom django.views.decorators.csrf import csrf_exempt\n\nfrom clixdev.apps.clix.models import *"]
 
     for endpoint in endpoints:
         misc = endpoint['misc']
@@ -257,7 +256,7 @@ def MODELS(app):
             else:
                 _class += f"\t{field[1]} = models.{type}(null={field[5]}, blank={field[6]}, unique={field[8]})\n"
 
-        _class += f'\tclass Meta:\n\t\tapp_label = "{app_name}"'
+        _class += f'\tclass Meta:\n\t\tapp_label = "clix"'
         _class += '\n'
     
     return f"""import uuid
@@ -271,7 +270,7 @@ from django.utils import timezone
 # preparing to remove due to beta
 def APP_URLS(app):
     endpoints = app['endpoints']
-    urls = [f"from django.urls import path\n\nfrom {app['name']}.views import *\n\nurlpatterns = ["]
+    urls = [f"from django.urls import path\n\nfrom clix.views import *\n\nurlpatterns = ["]
 
     for endpoint in endpoints:
         urls.append(
@@ -282,11 +281,10 @@ def APP_URLS(app):
 def ADMIN(app):
     # models = app.get('models')
     # registers = '\n'.join(['admin.site.register(' + model.get('table_name') + ')' for model in models])
-    return f"""from django.contrib import admin\nfrom clixdev.projects._models import *"""
+    return f"""from django.contrib import admin\nfrom clixdev.app.clix.models import *"""
 # removed for beta
 # {registers}
 
-
 def REQUIREMENTS():
     return """"""
 
